# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("Match _case")
msg0002 = _("Match _word")
msg0003 = _("_Previous")
msg0004 = _("_Next")
msg0005 = _("_Search for:")
msg0006 = _("Search for text")
msg0007 = _("Closed search bar")
msg0008 = _("Replac_e with:")
msg0009 = _("Search for and replace text")
msg0010 = _("Closed replace bar")
msg0011 = _("_Replace")
msg0012 = _("Replace _All")
msg0013 = _("Incre_mental")
